@@ -2,12 +2,13 @@
 #include <string.h>
 #include <ctype.h>
 #include "base64.h"
+#include <sys/types.h>
 
 namespace SWF {
 
-// ------------ utility functions
+// ------------ utility function
 
-long SWFBitsNeeded( long value, bool is_signed ) {
+int SWFBitsNeeded( int32_t value, bool is_signed ) {
 	long cnt;
 	if( is_signed ) {
 		if(value < 0) {
