@@ -9,7 +9,7 @@ namespace SWF {
 
 class Context;
 	
-long SWFBitsNeeded( long value, bool is_signed = false );
+int SWFBitsNeeded( int32_t value, bool is_signed = false );
 long SWFMaxBitsNeeded( bool is_signed, int how_many, ... );
 
 class Item {
