@@ -62,6 +62,40 @@ uint32_t Reader::getInt() {
 	return r;
 }
 
+float Reader::getFloat() {
+	if( pos+4 > length ) {
+		err = SWFR_EOF;
+		pos = length+1;
+		return 0;
+	}
+	// FIXME x86-centric?
+	int r = data[pos++];
+	r += data[pos++]<<8;
+	r += data[pos++]<<16;
+	r += data[pos++]<<24;
+	return *((float*)&r);
+}
+
+double Reader::getDouble() {
+	if( pos+8 > length ) {
+		err = SWFR_EOF;
+		pos = length+1;
+		return 0;
+	}
+	// FIXME x86-centric?
+	char value[8];
+	value[4] = data[pos++];
+	value[5] = data[pos++];
+	value[6] = data[pos++];
+	value[7] = data[pos++];
+	value[0] = data[pos++];
+	value[1] = data[pos++];
+	value[2] = data[pos++];
+	value[3] = data[pos++];
+
+	return *(double*)value;
+}
+
 double Reader::getFixed( int bytesize, int exp ) {
 	fprintf(stderr,"WARNING: Reader::getFixed is deprecated\n");
 	
