@@ -20,6 +20,8 @@ class Reader {
 		uint8_t getByte();
 		uint16_t getWord();
 		uint32_t getInt();
+		float getFloat();
+		double getDouble();
 		double getFixed( int bytesize, int decimals );
 		char *getString();
 		char *getPString();
