@@ -49,6 +49,35 @@ void Writer::putInt( uint32_t value ) {
 	data[pos++] = (value>>24)&0xFF;
 }
 
+void Writer::putFloat( float v ) {
+	byteAlign();
+	if( !assure( 4 ) ) return;
+
+	// FIXME x86-centric?
+	int value = *((int*)&v);
+	data[pos++] = value&0xFF;
+	data[pos++] = (value>>8)&0xFF;
+	data[pos++] = (value>>16)&0xFF;
+	data[pos++] = (value>>24)&0xFF;
+}
+
+void Writer::putDouble( double v ) {
+	byteAlign();
+	if( !assure( 8 ) ) return;
+	// FIXME x86-centric?
+	char value[8];
+	(*(double*)value) = v;
+	
+	data[pos++] = value[4];
+	data[pos++] = value[5];
+	data[pos++] = value[6];
+	data[pos++] = value[7];
+	data[pos++] = value[0];
+	data[pos++] = value[1];
+	data[pos++] = value[2];
+	data[pos++] = value[3];
+}
+
 void Writer::putFixed( double value, int bytesize, int exp ) {
 	if( !assure( bytesize ) ) return;
 
