@@ -127,11 +127,11 @@ void Transform::dump( int indent, Context *ctx ) {
 
 	print_indent(indent);
 	printf("scaleX: "); 
-	printf("%f\n", scaleX);
+	printf("%E\n", scaleX);
 
 	print_indent(indent);
 	printf("scaleY: "); 
-	printf("%f\n", scaleY);
+	printf("%E\n", scaleY);
 
 	}
 
@@ -148,11 +148,11 @@ void Transform::dump( int indent, Context *ctx ) {
 
 	print_indent(indent);
 	printf("skewX: "); 
-	printf("%f\n", skewX);
+	printf("%E\n", skewX);
 
 	print_indent(indent);
 	printf("skewY: "); 
-	printf("%f\n", skewY);
+	printf("%E\n", skewY);
 
 	}
 
@@ -1298,6 +1298,28 @@ void RemoveObject::dump( int indent, Context *ctx ) {
 
 }
 
+void DefineBits::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x06);
+	
+	
+	printf("DefineBits"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("data: "); 
+	printf("[Rest]\n");
+	data.dump( indent+1, ctx );
+
+}
+
 void SetBackgroundColor::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -2380,6 +2402,43 @@ void Export::dump( int indent, Context *ctx ) {
 
 }
 
+void Import::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x39);
+	
+	
+	printf("Import"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("url: "); 
+	printf("%s\n", url?url:"(nil)");
+
+	print_indent(indent);
+	printf("count: "); 
+	printf("%i\n", count);
+
+	print_indent(indent);
+	printf("symbols: "); 
+	{
+		printf("[list of Symbols]\n");
+		Symbol *item;
+		ListItem<Symbol>* i;
+		i = symbols.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+}
+
 void DoInitAction::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -2542,8 +2601,6 @@ void StackFloat::dump( int indent, Context *ctx ) {
 	
 	print_indent(indent);
 	printf("value: "); 
-	printf("%i\n", value);
-
 }
 
 void StackNull::dump( int indent, Context *ctx ) {
@@ -2619,8 +2676,6 @@ void StackDouble::dump( int indent, Context *ctx ) {
 	
 	print_indent(indent);
 	printf("value: "); 
-	printf("%i\n", value);
-
 }
 
 void StackInteger::dump( int indent, Context *ctx ) {
@@ -2636,8 +2691,6 @@ void StackInteger::dump( int indent, Context *ctx ) {
 	
 	print_indent(indent);
 	printf("value: "); 
-	printf("%i\n", value);
-
 }
 
 void StackDictionaryLookup::dump( int indent, Context *ctx ) {
@@ -3956,44 +4009,44 @@ void DeclareFunction2::dump( int indent, Context *ctx ) {
 	printf("%i\n", regc);
 
 	print_indent(indent);
-	printf("reserved: "); 
-	printf("%i\n", reserved);
-
-	print_indent(indent);
-	printf("preloadGlobal: "); 
-	printf("%i\n", preloadGlobal);
-
-	print_indent(indent);
-	printf("preloadParent: "); 
-	printf("%i\n", preloadParent);
-
-	print_indent(indent);
-	printf("preloadRoot: "); 
-	printf("%i\n", preloadRoot);
-
-	print_indent(indent);
-	printf("suppressSuper: "); 
-	printf("%i\n", suppressSuper);
-
-	print_indent(indent);
-	printf("preloadSuper: "); 
-	printf("%i\n", preloadSuper);
-
-	print_indent(indent);
-	printf("suppressArguments: "); 
-	printf("%i\n", suppressArguments);
-
-	print_indent(indent);
-	printf("preloadArguments: "); 
-	printf("%i\n", preloadArguments);
+	printf("preloadThis: "); 
+	printf("%i\n", preloadThis);
 
 	print_indent(indent);
 	printf("suppressThis: "); 
 	printf("%i\n", suppressThis);
 
 	print_indent(indent);
-	printf("preloadThis: "); 
-	printf("%i\n", preloadThis);
+	printf("preloadArguments: "); 
+	printf("%i\n", preloadArguments);
+
+	print_indent(indent);
+	printf("suppressArguments: "); 
+	printf("%i\n", suppressArguments);
+
+	print_indent(indent);
+	printf("preloadSuper: "); 
+	printf("%i\n", preloadSuper);
+
+	print_indent(indent);
+	printf("suppressSuper: "); 
+	printf("%i\n", suppressSuper);
+
+	print_indent(indent);
+	printf("preloadRoot: "); 
+	printf("%i\n", preloadRoot);
+
+	print_indent(indent);
+	printf("preloadParent: "); 
+	printf("%i\n", preloadParent);
+
+	print_indent(indent);
+	printf("preloadGlobal: "); 
+	printf("%i\n", preloadGlobal);
+
+	print_indent(indent);
+	printf("reserved: "); 
+	printf("%i\n", reserved);
 
 	print_indent(indent);
 	printf("args: "); 
@@ -4015,6 +4068,22 @@ void DeclareFunction2::dump( int indent, Context *ctx ) {
 	printf("length: "); 
 	printf("%i\n", length);
 
+	print_indent(indent);
+	printf("actions: "); 
+	{
+		printf("[list of Actions]\n");
+		Action *item;
+		ListItem<Action>* i;
+		i = actions.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
 }
 
 void Try::dump( int indent, Context *ctx ) {
