@@ -887,6 +887,19 @@ size_t RemoveObject::getSize( Context *ctx ) {
 	return r;
 }
 
+size_t DefineBits::getSize( Context *ctx ) {
+	size_t r = 0;
+	
+	r += 16;
+
+	r += data.getSize(ctx);
+
+	
+	r += Tag::getHeaderSize( r );
+//	printf("DefineBits sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );
+	return r;
+}
+
 size_t SetBackgroundColor::getSize( Context *ctx ) {
 	size_t r = 0;
 	
@@ -1567,6 +1580,32 @@ size_t Export::getSize( Context *ctx ) {
 	return r;
 }
 
+size_t Import::getSize( Context *ctx ) {
+	size_t r = 0;
+	
+	r += ((url ? strlen( url ) : 0)+1)*8;
+
+	r += 16;
+
+	{
+		Symbol* item;
+		ListItem<Symbol>* i;
+		i = symbols.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	
+	r += Tag::getHeaderSize( r );
+//	printf("Import sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );
+	return r;
+}
+
 size_t DoInitAction::getSize( Context *ctx ) {
 	size_t r = 0;
 	
@@ -2613,26 +2652,26 @@ size_t DeclareFunction2::getSize( Context *ctx ) {
 
 	r += 8;
 
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
 	r += 7;
 
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
 	{
 		Parameter* item;
 		ListItem<Parameter>* i;
@@ -2648,6 +2687,19 @@ size_t DeclareFunction2::getSize( Context *ctx ) {
 
 	r += 16;
 
+	{
+		Action* item;
+		ListItem<Action>* i;
+		i = actions.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx);
+			}
+			i = i->next();
+		}
+	}
+
 	
 	r += Action::getHeaderSize( r );
 //	printf("DeclareFunction2 sz %i bits (%.2f bytes)\n", r, ((float)r)/8 );
