@@ -3,6 +3,7 @@ const char *xslt_library =
 "<?xml version=\"1.0\"?>\n"
 "<xsl:stylesheet	xmlns:xsl=\"http://www.w3.org/1999/XSL/Transform\" \n"
 "				xmlns:swft=\"http://subsignal.org/swfml/swft\"\n"
+"				xmlns:str=\"http://exslt.org/strings\"\n"
 "				extension-element-prefixes=\"swft\"\n"
 "				version='1.0'>\n"
 "\n"
@@ -19,7 +20,8 @@ const char *xslt_library =
 "	</xsl:variable>\n"
 "	<xsl:variable name=\"compressed\">\n"
 "		<xsl:choose>\n"
-"			<xsl:when test=\"@compressed\"><xsl:value-of select=\"@compressed\"/></xsl:when>\n"
+"			<xsl:when test=\"@compressed='true'\">1</xsl:when>\n"
+"			<xsl:when test=\"@compressed='false'\">0</xsl:when>\n"
 "			<xsl:otherwise>1</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
@@ -67,16 +69,14 @@ const char *xslt_library =
 "			</size>\n"
 "			<tags>\n"
 "				<xsl:apply-templates/>\n"
-"				\n"
-"				<ShowFrame/>\n"
 "				<End/>\n"
 "			</tags>\n"
 "		</Header>\n"
 "	</swf>\n"
 "</xsl:template>\n"
 "\n"
-"<!-- background color -->\n"
-"<xsl:template match=\"background\">\n"
+"<!-- Color from @color=\"#rrggbb\" or @red, @green, @blue-->\n"
+"<xsl:template name=\"color\">\n"
 "	<xsl:variable name=\"red\">\n"
 "		<xsl:choose>\n"
 "			<xsl:when test=\"@red\"><xsl:value-of select=\"@red\"/></xsl:when>\n"
@@ -98,15 +98,51 @@ const char *xslt_library =
 "			<xsl:otherwise>200</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
+"	<Color red=\"{$red}\" green=\"{$green}\" blue=\"{$blue}\"/>\n"
+"</xsl:template>\n"
 "\n"
+"<!-- ColorRGBA from @color=\"#rrggbbaa\" or @red, @green, @blue, @alpha -->\n"
+"<xsl:template name=\"color-rgba\">\n"
+"	<xsl:variable name=\"red\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@red\"><xsl:value-of select=\"@red\"/></xsl:when>\n"
+"			<xsl:when test=\"@color\">0x<xsl:value-of select=\"substring(@color,2,2)\"/></xsl:when>\n"
+"			<xsl:otherwise>0</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"green\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@green\"><xsl:value-of select=\"@green\"/></xsl:when>\n"
+"			<xsl:when test=\"@color\">0x<xsl:value-of select=\"substring(@color,4,2)\"/></xsl:when>\n"
+"			<xsl:otherwise>0</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"blue\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@blue\"><xsl:value-of select=\"@blue\"/></xsl:when>\n"
+"			<xsl:when test=\"@color\">0x<xsl:value-of select=\"substring(@color,6)\"/></xsl:when>\n"
+"			<xsl:otherwise>0</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"alpha\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@alpha\"><xsl:value-of select=\"@alpha\"/></xsl:when>\n"
+"			<xsl:otherwise>255</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<ColorRGBA red=\"{$red}\" green=\"{$green}\" blue=\"{$blue}\" alpha=\"{$alpha}\"/>\n"
+"</xsl:template>\n"
+"\n"
+"<!-- background color -->\n"
+"<xsl:template match=\"background\">\n"
 "	<SetBackgroundColor>\n"
 "		<color>\n"
-"			<Color red=\"{$red}\" green=\"{$green}\" blue=\"{$blue}\"/>\n"
+"			<xsl:call-template name=\"color\"/>\n"
 "		</color>\n"
 "	</SetBackgroundColor>\n"
 "</xsl:template>\n"
 "\n"
-"<!-- library just passes thru, children decide wether to expord by themselves -->\n"
+"<!-- library just passes thru, children decide wether to export by themselves -->\n"
 "<xsl:template match=\"library\">\n"
 "	<xsl:apply-templates/>\n"
 "</xsl:template>\n"
@@ -154,14 +190,14 @@ const char *xslt_library =
 "		 that is already placed in layer (depth) -->\n"
 "	<xsl:variable name=\"replace\">\n"
 "		<xsl:choose>\n"
-"			<xsl:when test=\"preceding-sibling::place[@depth=$depth]\">1</xsl:when>\n"
+"			<xsl:when test=\"preceding-sibling::place[@depth=$depth] or ../preceding-sibling::frame/place[@depth=$depth]\">1</xsl:when>\n"
 "			<xsl:otherwise>0</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
 "	<xsl:if test=\"$replace = '1'\">\n"
 "		<RemoveObject2 depth=\"{@depth}\"/>\n"
 "	</xsl:if>\n"
-"	<PlaceObject2 replace=\"0\" morph=\"{$replace}\" depth=\"{$depth}\" objectID=\"{$id}\">\n"
+"	<PlaceObject2 replace=\"0\" morph=\"{$replace}\" depth=\"{$depth}\" objectID=\"{$id}\" name=\"{@name}\">\n"
 "		<transform>\n"
 "			<Transform transX=\"{$x}\" transY=\"{$y}\" scaleX=\"{$scale}\" scaleY=\"{$scale}\"/>\n"
 "		</transform>\n"
@@ -241,7 +277,8 @@ const char *xslt_library =
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
 "\n"
-"	<DefineEditText objectID=\"{$id}\" wordWrap=\"1\" multiLine=\"1\" password=\"0\" readOnly=\"0\" autoSize=\"0\" hasLayout=\"1\"\n"
+"	<DefineEditText objectID=\"{$id}\" wordWrap=\"1\" multiLine=\"1\" password=\"0\" \n"
+"		readOnly=\"0\" autoSize=\"0\" hasLayout=\"1\"\n"
 "		notSelectable=\"0\" hasBorder=\"0\" isHTML=\"0\" useOutlines=\"1\" \n"
 "		fontRef=\"{swft:map-id(@font)}\" fontHeight=\"{$size}\"\n"
 "		align=\"0\" leftMargin=\"0\" rightMargin=\"0\" indent=\"0\" leading=\"40\" \n"
@@ -250,13 +287,103 @@ const char *xslt_library =
 "			<Rectangle left=\"{$x}\" right=\"{$x + $width}\" top=\"{$y}\" bottom=\"{$y + $height}\"/>\n"
 "		</size>\n"
 "		<color>\n"
-"			<ColorRGBA red=\"51\" green=\"51\" blue=\"51\" alpha=\"255\"/>\n"
+"			<xsl:call-template name=\"color-rgba\"/>\n"
 "		</color>\n"
 "	</DefineEditText>\n"
 "\n"
 "</xsl:template>\n"
 "\n"
-"<!-- clip -->\n"
+"<!-- video object -->\n"
+"<xsl:template match=\"video\">\n"
+"	<xsl:variable name=\"id\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@id\">\n"
+"				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>\n"
+"				<xsl:value-of select=\"swft:next-id()\"/>\n"
+"			</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"frames\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@frames\"><xsl:value-of select=\"@frames\"/></xsl:when>\n"
+"			<xsl:otherwise>0</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"width\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@width\"><xsl:value-of select=\"@width\"/></xsl:when>\n"
+"			<xsl:otherwise>160</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"height\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@height\"><xsl:value-of select=\"@height\"/></xsl:when>\n"
+"			<xsl:otherwise>120</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"deblocking\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@deblocking\"><xsl:value-of select=\"@deblocking\"/></xsl:when>\n"
+"			<xsl:otherwise>0</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"smoothing\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@smoothing\">1</xsl:when>\n"
+"			<xsl:otherwise>0</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"codec\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@codec\"><xsl:value-of select=\"@codec\"/></xsl:when>\n"
+"			<xsl:otherwise>0</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<DefineVideoStream objectID=\"{$id}\" frames=\"{$frames}\" width=\"{$width}\" height=\"{$height}\" deblocking=\"{$deblocking}\" smoothing=\"{$smoothing}\" codec=\"{$codec}\"/>\n"
+"</xsl:template>\n"
+"\n"
+"<!-- frame -->\n"
+"<xsl:template match=\"frame\">\n"
+"	<xsl:apply-templates/>\n"
+"	<xsl:if test=\"@name\">\n"
+"		<FrameLabel label=\"{@name}\"/>\n"
+"	</xsl:if>\n"
+"	<ShowFrame/>\n"
+"</xsl:template>\n"
+"\n"
+"<!-- clips -->\n"
+"<xsl:template match=\"clip\" priority=\"-1\">\n"
+"	<xsl:variable name=\"id\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@id\">\n"
+"				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>\n"
+"				<xsl:value-of select=\"swft:next-id()\"/>\n"
+"			</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
+"		<tags>\n"
+"			<xsl:apply-templates/>\n"
+"			<End/>\n"
+"		</tags>\n"
+"	</DefineSprite>	\n"
+"	<xsl:if test=\"ancestor::library\">\n"
+"		<xsl:apply-templates select=\"*|@*\" mode=\"export\">\n"
+"			<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
+"		</xsl:apply-templates>\n"
+"	</xsl:if>\n"
+"	<xsl:if test=\"@class\">\n"
+"		<xsl:call-template name=\"register-class\">\n"
+"			<xsl:with-param name=\"class\" select=\"@class\"/>\n"
+"			<xsl:with-param name=\"linkage-id\" select=\"@id\"/>\n"
+"		</xsl:call-template>\n"
+"	</xsl:if>\n"
+"</xsl:template>\n"
+"\n"
 "<xsl:template match=\"clip[@import]\">\n"
 "	<xsl:variable name=\"id\">\n"
 "		<xsl:choose>\n"
@@ -272,10 +399,10 @@ const char *xslt_library =
 "		<xsl:value-of select=\"@import\"/>\n"
 "	</xsl:variable>\n"
 "	<xsl:variable name=\"ext\">\n"
-"		<xsl:value-of select=\"translate(substring-after(@import,'.'),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')\"/>\n"
+"		<xsl:value-of select=\"translate(substring(@import,string-length(@import)-2),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')\"/>\n"
 "	</xsl:variable>\n"
 "	<xsl:choose>\n"
-"		<xsl:when test=\"$ext = 'jpg' or $ext = 'jpeg'\">\n"
+"		<xsl:when test=\"$ext = 'jpg' or $ext = 'peg'\">\n"
 "			<xsl:apply-templates select=\"swft:import-jpeg($file)\" mode=\"makeswf\">\n"
 "				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
 "			</xsl:apply-templates>\n"
@@ -301,6 +428,12 @@ const char *xslt_library =
 "			<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
 "		</xsl:apply-templates>\n"
 "	</xsl:if>\n"
+"	<xsl:if test=\"@class\">\n"
+"		<xsl:call-template name=\"register-class\">\n"
+"			<xsl:with-param name=\"class\" select=\"@class\"/>\n"
+"			<xsl:with-param name=\"linkage-id\" select=\"@id\"/>\n"
+"		</xsl:call-template>\n"
+"	</xsl:if>\n"
 "</xsl:template>\n"
 "\n"
 "<xsl:template match=\"font[@import]\">\n"
@@ -335,7 +468,7 @@ const char *xslt_library =
 "	</DefineBitsJPEG2>\n"
 "	<DefineShape objectID=\"{$shapeID}\">\n"
 "		<bounds>\n"
-"			<Rectangle left=\"0\" right=\"{@width}\" top=\"0\" bottom=\"{@width}\"/>\n"
+"			<Rectangle left=\"0\" right=\"{@width}\" top=\"0\" bottom=\"{@height}\"/>\n"
 "		</bounds>\n"
 "		<styles>\n"
 "			<StyleList>\n"
@@ -387,7 +520,7 @@ const char *xslt_library =
 "	</DefineBitsLossless2>\n"
 "	<DefineShape objectID=\"{$shapeID}\">\n"
 "		<bounds>\n"
-"			<Rectangle left=\"0\" right=\"{@width}\" top=\"0\" bottom=\"{@width}\"/>\n"
+"			<Rectangle left=\"0\" right=\"{@width}\" top=\"0\" bottom=\"{@height}\"/>\n"
 "		</bounds>\n"
 "		<styles>\n"
 "			<StyleList>\n"
@@ -455,8 +588,26 @@ const char *xslt_library =
 "	<swft:pop-map/>\n"
 "</xsl:template>\n"
 "\n"
+"<!-- shared library import -->\n"
+"<xsl:template match=\"import\">\n"
+"	<Import url=\"{@url}\">\n"
+"		<symbols>\n"
+"			<xsl:if test=\"@symbol\">\n"
+"				<Symbol objectID=\"{swft:map-id(@symbol)}\" name=\"{@symbol}\"/>\n"
+"			</xsl:if>	\n"
+"			<xsl:if test=\"@file\">\n"
+"				<xsl:apply-templates select=\"swft:document(@file)/swf/Header/tags/Export/symbols/*\" mode=\"import\"/>\n"
+"			</xsl:if>\n"
+"		</symbols>\n"
+"	</Import>\n"
+"</xsl:template>\n"
+"\n"
+"<xsl:template match=\"Symbol\" mode=\"import\">\n"
+"	<Symbol objectID=\"{swft:map-id(@name)}\" name=\"{@name}\"/>\n"
+"</xsl:template>\n"
+"\n"
 "<!-- global id remapping -->\n"
-"<xsl:template match=\"@objectID|@fontRef\" mode=\"idmap\">\n"
+"<xsl:template match=\"@objectID|@fontRef|@sprite\" mode=\"idmap\">\n"
 "	<xsl:attribute name=\"{name()}\"><xsl:value-of select=\"swft:map-id(.)\"/></xsl:attribute>\n"
 "</xsl:template>\n"
 "<xsl:template match=\"*|@*|text()\" mode=\"idmap\" priority=\"-1\">\n"
@@ -479,65 +630,190 @@ const char *xslt_library =
 "<xsl:template match=\"*|@*|text()\" mode=\"sprite-local\" priority=\"-1\"/>\n"
 "\n"
 "\n"
-"<!-- import SWF as shared library -->\n"
-"<!--\n"
-"<xsl:template match=\"swf\">\n"
-"	<xsl:variable name=\"id\">\n"
-"		<xsl:choose>\n"
-"			<xsl:when test=\"@id\">\n"
-"				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
-"			</xsl:when>\n"
-"			<xsl:otherwise>\n"
-"				<xsl:value-of select=\"swft:next-id()\"/>\n"
-"			</xsl:otherwise>\n"
-"		</xsl:choose>\n"
-"	</xsl:variable>\n"
-"\n"
-"	<xsl:apply-templates select=\"swft:document(@file)\" mode=\"makeswf\">\n"
-"		<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
-"	</xsl:apply-templates>\n"
-"	\n"
-"	<xsl:apply-templates select=\"*|@*\" mode=\"export\">\n"
-"		<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
-"	</xsl:apply-templates>\n"
-"\n"
-"</xsl:template>\n"
-"\n"
-"<xsl:template match=\"swf\" mode=\"makeswf\">\n"
-"	<swft:push-map/>\n"
-"	<xsl:param name=\"id\"/>\n"
-"	<xsl:variable name=\"swfID\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
-"	\n"
-"	<xsl:apply-templates select=\"Header/tags/*\" mode=\"sprite-global\"/>\n"
-"		\n"
-"	<DefineSprite objectID=\"{$swfID}\" frames=\"{count(Header/tags/ShowFrame)}\">\n"
-"		<tags>\n"
-"			<xsl:apply-templates select=\"Header/tags/*\" mode=\"sprite-local\"/>\n"
-"		</tags>\n"
-"	</DefineSprite>\n"
-"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
-"		<tags>\n"
-"			<PlaceObject2 replace=\"0\" depth=\"1\" objectID=\"{$swfID}\">\n"
-"				<transform>\n"
-"					<Transform transX=\"0\" transY=\"0\" />\n"
-"				</transform>\n"
-"			</PlaceObject2>\n"
-"			<ShowFrame/>\n"
-"			<End/>\n"
-"		</tags>\n"
-"	</DefineSprite>\n"
-"	<swft:pop-map/>\n"
-"</xsl:template>\n"
-"-->\n"
-"\n"
 "<!-- TTF import -->\n"
 "<xsl:template match=\"ttf\" mode=\"makeswf\">\n"
 "	<xsl:param name=\"id\"/>\n"
-"	<DefineFont2 objectID=\"{$id}\" name=\"{@name}\">\n"
+"	<DefineFont2 objectID=\"{$id}\">\n"
 "		<xsl:apply-templates select=\"DefineFont2/*|DefineFont2/@*[name() != 'objectID']\"/>\n"
 "	</DefineFont2>\n"
 "</xsl:template>\n"
 "\n"
+"<!-- call -->\n"
+"<xsl:template match=\"call\">\n"
+"	<xsl:variable name=\"object\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@object\"><xsl:value-of select=\"@object\"/></xsl:when>\n"
+"			<xsl:otherwise>Main</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"method\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@method\"><xsl:value-of select=\"@method\"/></xsl:when>\n"
+"			<xsl:otherwise>main</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"spriteid\">\n"
+"		<xsl:value-of select=\"swft:next-id()\"/>\n"
+"	</xsl:variable>\n"
+"	<DefineSprite objectID=\"{$spriteid}\" frames=\"1\">\n"
+"		<tags>\n"
+"			<End/>\n"
+"		</tags>\n"
+"	</DefineSprite>\n"
+"	<Export>\n"
+"		<symbols>\n"
+"			<Symbol objectID=\"{$spriteid}\" name=\"__Packages.swfmill.call.{$object}.{$method}\"/>\n"
+"		</symbols>\n"
+"	</Export>\n"
+"	<DoInitAction sprite=\"{$spriteid}\">\n"
+"		<actions>\n"
+"			<PushData>\n"
+"				<items>\n"
+"					<StackString value=\"{@object}\"/>\n"
+"				</items>\n"
+"			</PushData>\n"
+"			<GetVariable/>\n"
+"			<PushData>\n"
+"				<items>\n"
+"					<StackString value=\"{@method}\"/>\n"
+"				</items>\n"
+"			</PushData>\n"
+"			<CallMethod/>\n"
+"			<Pop/>\n"
+"			<EndAction/>\n"
+"		</actions>\n"
+"	</DoInitAction>\n"
+"</xsl:template>\n"
+"\n"
+"<xsl:template name=\"register-class\">\n"
+"	<xsl:param name=\"class\"/>\n"
+"	<xsl:param name=\"linkage-id\"/>\n"
+"	<xsl:variable name=\"packages\" select=\"str:tokenize($class,'.')\"/>\n"
+"	<xsl:variable name=\"strofs\">3</xsl:variable>\n"
+"	<xsl:variable name=\"id\" select=\"swft:next-id()\"/>\n"
+"	\n"
+"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
+"		<tags>\n"
+"		  <End/>\n"
+"		</tags>\n"
+"	</DefineSprite>\n"
+"	<Export>\n"
+"		<symbols>\n"
+"		  <Symbol objectID=\"{$id}\" name=\"__Packages.swfmill.registerClass.{$linkage-id}\"/>\n"
+"		</symbols>\n"
+"	</Export>\n"
+"	<DoInitAction sprite=\"{$id}\">\n"
+"		<actions>\n"
+"			<Dictionary>\n"
+"				<strings>\n"
+"					<String value=\"Object\"/>\n"
+"					<String value=\"registerClass\"/>\n"
+"					<String value=\"{$linkage-id}\"/>\n"
+"					<xsl:for-each select=\"$packages\">\n"
+"						<String value=\"{.}\"/>\n"
+"					</xsl:for-each>\n"
+"				</strings>\n"
+"			</Dictionary>\n"
+"			\n"
+"			<!-- package root -->\n"
+"			<PushData>\n"
+"				<items>\n"
+"				  <StackDictionaryLookup index=\"{$strofs}\"/> \n"
+"				</items>\n"
+"			</PushData>\n"
+"			<GetVariable/>\n"
+"			\n"
+"			<!-- packages -->\n"
+"			<xsl:for-each select=\"$packages[position()>1]\">\n"
+"				<PushData>\n"
+"					<items>\n"
+"					  <StackDictionaryLookup index=\"{$strofs + position()}\"/>\n"
+"					</items>\n"
+"				</PushData>\n"
+"				<GetMember/>\n"
+"			</xsl:for-each>\n"
+"			\n"
+"			<!-- linkage id, 2 (arguments), Object-->\n"
+"			<PushData>\n"
+"				<items>\n"
+"				  <StackDictionaryLookup index=\"2\"/>\n"
+"				  <StackInteger value=\"2\"/>\n"
+"				  <StackDictionaryLookup index=\"0\"/>\n"
+"				</items>\n"
+"			</PushData>\n"
+"			<GetVariable/>\n"
+"			<!-- registerClass -->\n"
+"			<PushData>\n"
+"				<items>\n"
+"				  <StackDictionaryLookup index=\"1\"/>\n"
+"				</items>\n"
+"			</PushData>\n"
+"			<CallMethod/>\n"
+"			<Pop/>\n"
+"			<EndAction/>\n"
+"		</actions>\n"
+"	</DoInitAction>\n"
+"	\n"
+"</xsl:template>\n"
+"\n"
+"<xsl:template match=\"set\">\n"
+"	<xsl:variable name=\"spriteid\">\n"
+"		<xsl:value-of select=\"swft:next-id()\"/>\n"
+"	</xsl:variable>\n"
+"	<DefineSprite objectID=\"{$spriteid}\" frames=\"1\">\n"
+"		<tags>\n"
+"			<End/>\n"
+"		</tags>\n"
+"	</DefineSprite>\n"
+"	<Export>\n"
+"		<symbols>\n"
+"			<Symbol objectID=\"{$spriteid}\" name=\"__Packages.swfmill.set.{@name}.{@member}\"/>\n"
+"		</symbols>\n"
+"	</Export>\n"
+"	<DoInitAction sprite=\"{$spriteid}\">\n"
+"		<actions>\n"
+"			<Dictionary>\n"
+"				<strings>\n"
+"					<String value=\"_root\"/>\n"
+"					<String value=\"{@name}\"/>\n"
+"					<String value=\"{@member}\"/>\n"
+"					<String value=\"{@value}\"/>\n"
+"				</strings>\n"
+"			</Dictionary>\n"
+"			<PushData>\n"
+"				<items>\n"
+"					<StackDictionaryLookup index=\"0\"/>\n"
+"				</items>\n"
+"			</PushData>\n"
+"			<GetVariable/>\n"
+"			<PushData>\n"
+"				<items>\n"
+"					<StackDictionaryLookup index=\"1\"/>\n"
+"				</items>\n"
+"			</PushData>\n"
+"			<GetMember/>\n"
+"			<PushData>\n"
+"				<items>\n"
+"					<StackDictionaryLookup index=\"2\"/>\n"
+"					<StackDictionaryLookup index=\"3\"/>\n"
+"				</items>\n"
+"			</PushData>\n"
+"			<SetMember/>\n"
+"			<EndAction/>\n"
+"		</actions>\n"
+"	</DoInitAction>\n"
+"</xsl:template>\n"
+"\n"
+"<!-- stop -->\n"
+"<xsl:template match=\"stop\">\n"
+"	<DoAction>\n"
+"		<actions>\n"
+"			<Stop/>\n"
+"			<EndAction/>\n"
+"		</actions>\n"
+"	</DoAction>\n"
+"</xsl:template>\n"
+"\n"
 "\n"
 "<!-- HTML wrapper -->\n"
 "<xsl:template match=\"html-wrapper\">\n"
